@@ -71,12 +71,15 @@ print.copulaSampleSel <- function(x, ...){
   if(!is.null(x$X3) && !is.null(x$X4) && !is.null(x$X5)){
   
   cat("\nEQUATION 3")
-  if(!(x$margins[2] %in% c("TW"))) cat("\nLink function for sigma:","log","\n") else cat("\nLink function for sigma:","qlogis","\n")  
+  # if(!(x$margins[2] %in% c("TW"))) 
+  cat("\nLink function for sigma:","log","\n") #else cat("\nLink function for sigma:","qlogis","\n")  
   cat("Formula: "); print(x$formula[[3]]) 
   
   
   cat("\nEQUATION 4")
-  if(x$margins[2] %in% c("DAGUM","SM","TW")) cat("\nLink function for nu:","log","\n")  
+  if(x$margins[2] %in% c("DAGUM","SM")) cat("\nLink function for nu:","log","\n")  
+  if(x$margins[2] %in% c("TW")) cat("\nLink function for nu:","qlogis","\n")  
+
   cat("Formula: "); print(x$formula[[4]]) 
     
 
